@@ -10,29 +10,61 @@ from .publisher import OFFG, PHIL, SCRA, get_publisher_label
 
 
 class Report(BaseModel):
-    """Pre-defined regex group names will enable the extraction
-    of the Report's fields.
+    """The `REPORT_PATTERN` is a `re.Pattern` object that contains pre-defined regex
+    group names. These group names can be mapped to this model's fields:
 
-    It's important that each field be
-    optional since the class is going to be joined to another
-    `BaseModel` object, i.e. the `Docket`.
+    Field | Type | Description
+    --:|:--:|:--
+    `publisher` | optional (str) | Type of the publisher.
+    `volume` | optional (str) | Publisher volume number.
+    `page` | optional (str) | Publisher volume page.
+    `volpubpage` | optional (str) | Combined fields: <volume> <publisher> <page>
+    `report_date` | optional (date) | Optional date associated with the report citation
 
-    In other words, the `Report` object is only one part of
-    the `Citation` object. It's possible for a `Citation` object to:
+    It's important that each field be **optional**. The `Report` will be joined
+    to another `BaseModel` object, i.e. the `Docket`, in a third-party library.
+    It must be stressed that the `Report` object is only one part of
+    the eventual `DockerReportCitation` object. It can:
 
     1. have both a `Docket` and a `Report`,
     2. have just a `Docket`;
     3. have just a `Report`.
-
-    The reason for optional fields is to take these scenarios into account
-    using the same model.
     """
 
-    publisher: str | None = Field(None, title="Type of the publisher.")
-    volume: str | None = Field(None, title="Publisher volume number.")
-    page: str | None = Field(None, title="Publisher volume page.")
-    volpubpage: str | None = Field(None, title="Combined fields.")
-    report_date: datetime.date | None = None
+    publisher: str | None = Field(
+        None,
+        title="Report Publisher",
+        description=(
+            "Shorthand label of the publisher involved, e.g. SCRA, Phil. Offg"
+        ),
+        max_length=5,
+    )
+    volume: str | None = Field(
+        None,
+        title="Volume Number",
+        description=(
+            "Publisher volume number - may not be a full digit since it can"
+            " exceptionally include letters."
+        ),
+        max_length=10,
+    )
+    page: str | None = Field(
+        None,
+        title="Page Number",
+        description="The page number of the publisher volume involved",
+        max_length=5,
+    )
+    volpubpage: str | None = Field(
+        None,
+        title="Volume Publisher Page",
+        description="Full expression of the report citation",
+        max_length=20,
+    )
+    report_date: datetime.date | None = Field(
+        None,
+        title="Report Date",
+        description="Exceptionally, report citations reference dates.",
+    )
 
     def __str__(self) -> str:
         return self.volpubpage or ""
