@@ -67,3 +67,21 @@ extra = rf"""
 REPORT_REGEX = rf"{volpubpage}{extra}"
 
 REPORT_PATTERN: Pattern = re.compile(REPORT_REGEX, re.X | re.I)
+"""A compiled regex expression that enables capturing the
+parts of a report.
+
+Examples:
+    >>> from citation_report import REPORT_PATTERN
+    >>> text = "42 SCRA 109, 117-118, October 29, 1971;"
+    >>> sample_match = REPORT_PATTERN.search(text)
+    >>> sample_match.group("volpubpage")
+    '42 SCRA 109'
+    >>> sample_match.group("volume")
+    '42 SCRA 109'
+    >>> sample_match.group("publisher")
+    'SCRA'
+    >>> sample_match.group("page")
+    '109'
+    >>> sample_match.group("report_date")
+    'October 29, 1971'
+"""
